/* -------------------------------------------------------------------------- *
 *                    OpenSim:  TugOfWar1_CreateModel.cpp                     *
 * -------------------------------------------------------------------------- *
 * The OpenSim API is a toolkit for musculoskeletal modeling and simulation.  *
 * See http://opensim.stanford.edu and the NOTICE file for more information.  *
 * OpenSim is developed at Stanford University and supported by the US        *
 * National Institutes of Health (U54 GM072970, R24 HD065690) and by DARPA    *
 * through the Warrior Web program.                                           *
 *                                                                            *
 * Copyright (c) 2005-2012 Stanford University and the Authors                *
 * Author(s): Jeffrey A. Reinbolt, Ayman Habib, Ajay Seth, Jack Middleton,    *
 *            Samuel R. Hamner                                                *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may    *
 * not use this file except in compliance with the License. You may obtain a  *
 * copy of the License at http://www.apache.org/licenses/LICENSE-2.0.         *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 * -------------------------------------------------------------------------- */

/* 
 *  Below is an example of an OpenSim application that provides its own 
 *  main() routine.  This application is a forward simulation of tug-of-war between two
 *  muscles pulling on a block.
 */

// Author:  Jeff Reinbolt, Ayman Habib, Ajay Seth, Jack Middleton, Samuel Hamner

//==============================================================================
//==============================================================================
#include <OpenSim/OpenSim.h>
//#include <OpenSim/Simulation/Model/CoordinateSet.h>
//#include <OpenSim/Tools\InverseDynamicsTool.h>
#include <OpenSim/Common/Array.h>
//#include <OpenSim/Tools/ScaleTool.h>


using namespace OpenSim;
using namespace SimTK;

//______________________________________________________________________________
/**
 * First exercise: create a model that does nothing. 
 */
int main()
{
	try {
			Model osimModel("D:/Gait2392_Simbody/gait2392_simbody.osim");

			/////////////////////  Problem one:  vusalization ///////////////////////////////////////
			osimModel.setUseVisualizer(true);
			State& stat=osimModel.initSystem();  //Initializing the model
			osimModel.getVisualizer().show(stat);
			////////////////////////////////////////////////////////////////////////////////////////////////////


			/////////////////////  Problem two:  ScaleTool ///////////////////////////////////////
	        // Whether or not use xml file to construct the ScaleTool object, 
			//setSubjectMass will cause unhandled exception

		    std::unique_ptr<ScaleTool> scl_tol(new ScaleTool(/*"D:/Gait2392_Simbody/subject01_Setup_Scale.xml"*/));
		 
			scl_tol->setName("abc");
		
			scl_tol->setSubjectMass(72.6);
			scl_tol->setSubjectHeight(1803.4);
		
			scl_tol->getModelScaler().setApply(1);
			scl_tol->getModelScaler().setMarkerFileName("D:/Gait2392_Simbody/subject01_static.trc");
			scl_tol->getModelScaler().setOutputModelFileName("D:/Gait2392_Simbody/Gait2392_scaled.osim");
			}
	////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

		catch (OpenSim::Exception ex)
		{
			std::cout << ex.getMessage() << std::endl;
			return 1;
		}
		catch (std::exception ex)
		{
			std::cout << ex.what() << std::endl;
			return 1;
		}
		catch (...)
		{
			std::cout << "UNRECOGNIZED EXCEPTION" << std::endl;
			return 1;
		}


		std::cin.get();
		return 0;


	return 0;
}

